@@ -22,11 +22,9 @@
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 # SOFTWARE.
 
-from __future__ import print_function, division, absolute_import
-
 
 __project__ = "pigit"
-__version__ = "1.3.0"
+__version__ = "1.3.1"
 __url__ = "https://github.com/zlj-zz/pigit.git"
 __uri__ = __url__
 
@@ -41,7 +39,6 @@ import os
 import sys
 import argparse
 import logging
-import logging.handlers
 import textwrap
 from distutils.util import strtobool
 from shutil import get_terminal_size
@@ -50,7 +47,12 @@ from typing import Optional
 from .log import LogHandle
 from .utils import confirm, color_print, is_color
 from .common import Color, Fx, TermColor
-from .git_utils import Git_Version, Repository_Path, repository_info, git_local_config
+from .git_utils import (
+    Git_Version,
+    REPOSITORY_PATH,
+    output_repository_info,
+    output_git_local_config,
+)
 from .decorator import time_it
 from .codecounter import CodeCounter
 from .shell_completion import ShellCompletion, process_argparse
@@ -97,12 +99,12 @@ class Config(object):
         """\
         #? Config file for pigit v. {version}
 
-        #  ____ ___ ____ ___ _____                            __ _                       _   _
-        # |  _ \_ _/ ___|_ _|_   _|           ___ ___  _ __  / _(_) __ _ _   _ _ __ __ _| |_(_) ___  _ __
-        # | |_) | | |  _ | |  | |_____ _____ / __/ _ \| '_ \| |_| |/ _` | | | | '__/ _` | __| |/ _ \| '_ \\
-        # |  __/| | |_| || |  | |_____|_____| (_| (_) | | | |  _| | (_| | |_| | | | (_| | |_| | (_) | | | |
-        # |_|  |___\____|___| |_|            \___\___/|_| |_|_| |_|\__, |\__,_|_|  \__,_|\__|_|\___/|_| |_|
-        #                                                          |___/
+        #  ____ ___ ____ ___ _____                            __ _
+        # |  _ \\_ _/ ___|_ _|_   _|           ___ ___  _ __  / _(_) __ _
+        # | |_) | | |  _ | |  | |_____ _____ / __/ _ \\| '_ \\| |_| |/ _` |
+        # |  __/| | |_| || |  | |_____|_____| (_| (_) | | | |  _| | (_| |
+        # |_|  |___\\____|___| |_|            \\___\\___/|_| |_|_| |_|\\__, |
+        #                                     {version:>20} |___/
         # Git-tools -- pigit configuration.
 
         # Show original git command.
@@ -117,14 +119,13 @@ class Config(object):
         # Display time of help information in interactive mode, 0 is permanent.
         gitprocessor_interactive_help_showtime={gitprocessor_interactive_help_showtime}
 
-
         # Whether to use the ignore configuration of the `.gitignore` file.
         codecounter_use_gitignore={codecounter_use_gitignore}
 
-        # Wether show files that cannot be counted.
+        # Whether show files that cannot be counted.
         codecounter_show_invalid={codecounter_show_invalid}
 
-        # Wether show files icons. Font support required, like: 'Nerd Font'
+        # Whether show files icons. Font support required, like: 'Nerd Font'
         codecounter_show_icon={codecounter_show_icon}
 
         # Output format of statistical results.
@@ -132,10 +133,12 @@ class Config(object):
         # When the command line width is not enough, the `simple ` format is forced.
         codecounter_result_format={codecounter_result_format}
 
-
         # Timeout for getting `.gitignore` template from net.
         gitignore_generator_timeout={gitignore_generator_timeout}
 
+        # Git local config print format.
+        # Supported: [table, normal]
+        git_config_format={git_config_format}
 
         # Control which parts need to be displayed when viewing git repository information.
         repository_show_path={repository_show_path}
@@ -144,13 +147,13 @@ class Config(object):
         repository_show_lastest_log={repository_show_lastest_log}
         repository_show_summary={repository_show_summary}
 
-        # Wether with color when use `-h` get help message.
+        # Whether with color when use `-h` get help message.
         help_use_color={help_use_color}
 
         # The max line width when use `-h` get help message.
         help_max_line_width={help_max_line_width}
 
-        # Wether run PIGIT in debug mode.
+        # Whether run PIGIT in debug mode.
         debug_mode={debug_mode}
 
         """
@@ -163,6 +166,7 @@ class Config(object):
         'codecounter_use_gitignore', 'codecounter_show_invalid',
         'codecounter_result_format', 'codecounter_show_icon',
         'gitignore_generator_timeout',
+        'git_config_format',
         'repository_show_path', 'repository_show_remote', 'repository_show_branchs',
         'repository_show_lastest_log', 'repository_show_summary',
         'help_use_color', 'help_max_line_width',
@@ -184,6 +188,9 @@ class Config(object):
 
     gitignore_generator_timeout: int = 60
 
+    git_config_format: str = "table"
+    _supported_git_config_format: list = ["normal", "table"]
+
     repository_show_path: bool = True
     repository_show_remote: bool = True
     repository_show_branchs: bool = True
@@ -193,7 +200,7 @@ class Config(object):
     help_use_color: bool = True
     help_max_line_width: int = 90
 
-    debug_mode: str = False
+    debug_mode: bool = False
 
     # Store warning messages.
     warnings: list = []
@@ -227,9 +234,11 @@ class Config(object):
                         # invalid line.
                         continue
                     key, line = line.split("=", maxsplit=1)
+
                     # processing.
                     key = key.strip()
                     line = line.strip().strip('"')
+
                     # checking.
                     if key not in self._keys:
                         self.warnings.append("'{0}' is not be supported!".format(key))
@@ -263,9 +272,9 @@ class Config(object):
                             continue
                         new_config[key] = str(line)
         except Exception as e:
-            Log.error(str(e))
+            Log.error(str(e) + str(e.__traceback__))
 
-        if (  # check codecounter output format wether supported.
+        if (  # check codecounter output format whether supported.
             "codecounter_result_format" in new_config
             and new_config["codecounter_result_format"]
             not in self._supported_result_format
@@ -277,7 +286,25 @@ class Config(object):
                 )
             )
 
-        if "version" in new_config and new_config["version"] != __version__:
+        if (
+            "git_config_format" in new_config
+            and new_config["git_config_format"] not in self._supported_git_config_format
+        ):
+            new_config["git_config_format"] = "==error=="
+            self.warnings.append(
+                'Config key "{0}" support must in {1}'.format(
+                    "git_config_format", self._supported_git_config_format
+                )
+            )
+
+        if "version" in new_config and not (
+            # If current version is a [beta] verstion then will not tip.
+            # Else if version is not right will tip.
+            new_config["version"] == __version__
+            or "beta" in __version__
+            or "alpha" in __version__
+        ):
+            print(new_config["version"])
             self.warnings.append(
                 "The current configuration file is not up-to-date."
                 "You'd better recreate it."
@@ -292,7 +319,7 @@ class Config(object):
         if os.path.exists(self.config_path) and not confirm(
             "Configuration exists, overwrite? [y/n]"
         ):
-            return
+            return None
 
         # Try to load already has config.
         conf = self.load_config()
@@ -307,10 +334,11 @@ class Config(object):
                 self.config_path, "w" if os.path.isfile(self.config_path) else "x"
             ) as f:
                 f.write(self.CONFIG_TEMPLATE.format(**conf))
-            print("Successful.")
         except Exception as e:
-            Log.error(str(e))
+            Log.error(str(e) + str(e.__traceback__))
             print("Failed, create config.")
+        else:
+            print("Successful.")
 
 
 CONFIG = Config()
@@ -378,9 +406,18 @@ def get_extra_cmds() -> dict:
     if os.path.isfile(extra_cmd_path):
         try:
             extra_cmd = imp.load_source("extra_cmd", extra_cmd_path)
-            extra_cmds = extra_cmd.extra_cmds
-        except Exception:
-            pass
+        except Exception as e:
+            Log.error(
+                "Can't load file '{0}';{1};{2}".format(
+                    extra_cmd_path, str(e), str(e.__traceback__)
+                )
+            )
+        else:
+            try:
+                extra_cmds = extra_cmd.extra_cmds
+            except AttributeError:
+                Log.error("Can't found dict name is 'extra_cmds'.")
+
     # print(extra_cmds)
     return extra_cmds
 
@@ -591,23 +628,27 @@ class Parser(object):
             return self._parser.parse_known_args(custom_commands)
         return self._parser.parse_known_args()
 
-    def process(self, known_args, extra_unknown: Optional[list] = None):
+    def process(self, known_args, extra_unknown: Optional[list] = None) -> None:
         try:
             if known_args.complete:
+                # Generate competion vars dict.
                 completion_vars = {
                     key: value.get("help", "") for key, value in Git_Cmds.items()
                 }
+
+                # Update var dict with shell command.
                 completion_vars.update(process_argparse(self._parser))
+
                 ShellCompletion(
                     __project__, completion_vars, PIGIT_HOME
                 ).complete_and_use()
-                return
+                return None
 
             if known_args.config:
-                git_local_config()
+                output_git_local_config(CONFIG.git_config_format)
 
             if known_args.information:
-                repository_info(
+                output_repository_info(
                     show_path=CONFIG.repository_show_path,
                     show_remote=CONFIG.repository_show_remote,
                     show_branches=CONFIG.repository_show_branchs,
@@ -616,15 +657,14 @@ class Parser(object):
                 )
 
             if known_args.create_config:
-                CONFIG.create_config_template()
-                return
+                return CONFIG.create_config_template()
 
             if known_args.ignore_type:
                 GitignoreGenetor(timeout=CONFIG.gitignore_generator_timeout,).launch(
                     known_args.ignore_type,
-                    dir_path=Repository_Path,
+                    dir_path=REPOSITORY_PATH,
                 )
-                return
+                return None
 
             if known_args.count:
                 path = known_args.count if known_args.count != "." else os.getcwd()
@@ -637,7 +677,7 @@ class Parser(object):
                 ).count_and_format_print(
                     show_invalid=CONFIG.codecounter_show_invalid,
                 )
-                return
+                return None
 
             git_processor = GitProcessor(
                 extra_cmds=get_extra_cmds(),
@@ -682,7 +722,7 @@ class Parser(object):
                                     pigit.tomato.help("tomato")
                     else:
                         os.system(command)
-                return
+                return None
 
             if known_args.shell:
                 _shell_mode()
@@ -703,21 +743,19 @@ class Parser(object):
                     command = known_args.command
                     known_args.args.extend(extra_unknown)  # type: list
                     git_processor.process_command(command, known_args.args)
-                    return
+                    return None
 
             # Don't have invalid command list.
             if not list(filter(lambda x: x, vars(known_args).values())):
                 introduce()
         except (KeyboardInterrupt, EOFError):
             raise SystemExit(0)
-            pass
 
 
 @time_it
 def main(custom_commands: Optional[list] = None):
-    # init_hook()
-
     parser = Parser()
+
     # parse custom comand, if has.
     if custom_commands is not None:
         stdargs = parser.parse(custom_commands)
