@@ -1,20 +1,24 @@
 # -*- coding:utf-8 -*-
 
-from functools import reduce
 import os
 import stat
 import re
 import json
-import threading
 import time
-from math import ceil
+import logging
+import threading
 import concurrent.futures
-from shutil import get_terminal_size
+from math import ceil
+from shutil import get_terminal_size, register_unpack_format
 from typing import Optional
 
 from .utils import confirm
-from .str_utils import shorten, get_file_icon
-from .common import Color, Fx
+from .common import Color, Fx, Symbol
+from .common.str_utils import shorten, get_file_icon, adjudgment_type
+from .common.str_table import Table
+
+
+Log = logging.getLogger(__name__)
 
 
 class CodeCounterError(Exception):
@@ -83,72 +87,6 @@ class CodeCounter(object):
         },
     ]
 
-    # Mark the type corresponding to the file suffix.
-    Suffix_Types: dict[str, str] = {
-        "": "",
-        "bat": "Batch",
-        "c": "C",
-        "conf": "Properties",
-        "cfg": "Properties",
-        "cpp": "C++",
-        "cs": "C#",
-        "css": "CSS",
-        "dart": "Dart",
-        "dea": "XML",
-        "go": "Go",
-        "gradle": "Groovy",
-        "h": "C",
-        "hpp": "C++",
-        "htm": "HTML",
-        "html": "HTML",
-        "java": "Java",
-        "js": "Java Script",
-        "jsx": "React",
-        "json": "Json",
-        "kt": "Kotlin",
-        "launch": "XML",
-        "less": "CSS",
-        "lua": "Lua",
-        "markdown": "Markdown",
-        "md": "Markdown",
-        "msg": "ROS Message",
-        "php": "PHP",
-        "py": "Python",
-        "plist": "XML",
-        "properties": "Propertie",
-        "r": "R",
-        "rc": "Properties",
-        "rb": "Ruby",
-        "rs": "Rust",
-        "rst": "reStructuredText",
-        "rviz": "YAML",
-        "ts": "Type Script",
-        "tsx": "React",
-        "sass": "CSS",
-        "scss": "CSS",
-        "sh": "Shell",
-        "sql": "SQL",
-        "swift": "Swift",
-        "srdf": "YAML",
-        "srv": "ROS Message",
-        "toml": "Properties",
-        "urdf": "XML",
-        "vim": "Vim Scirpt",
-        "vue": "Vue",
-        "xhtml": "HTML",
-        "xml": "XML",
-        "yaml": "YAML",
-        "yml": "YAML",
-        "zsh": "Shell",
-    }
-
-    # Mark the type of some special files.
-    Special_Names: dict[str, str] = {
-        "requirements.txt": "Pip requirement",
-        "license": "LICENSE",
-        "vimrc": "Vim Scirpt",
-    }
-
     # Colors displayed for different code quantities.
     level_color: list[str] = [
         "",
@@ -177,10 +115,10 @@ class CodeCounter(object):
         """
         Args:
             count_path (str, optional): The path of needed count. Defaults to os.getcwd().
-            use_ignore (bool, optional): Wether detect `.gitignore` file. Defaults to True.
+            use_ignore (bool, optional): Whether detect `.gitignore` file. Defaults to True.
             result_saved_path (str, optional): Result save path. Defaults to "".
             result_format (str, optional): Output format string. Defaults to "table".
-            use_icon (bool, optional): Wether output with icon. Defaults to False.
+            use_icon (bool, optional): Whether output with icon. Defaults to False.
 
         Raises:
             CodeCounterError: when format string not right.
@@ -199,6 +137,7 @@ class CodeCounter(object):
             )
         self.result_format = result_format
         self.use_icon = use_icon
+        self.rune = Symbol.rune["bold"]
 
     def process_gitignore(self, root: str) -> None:
         """Process `.gitignore` files and add matching rules.
@@ -225,7 +164,7 @@ class CodeCounter(object):
                 )
         except PermissionError:
             if confirm(
-                "Can't read {0}, wether get jurisdiction[y/n]:".format(ignore_path)
+                "Can't read {0}, whether get jurisdiction[y/n]:".format(ignore_path)
             ):
                 os.chmod(ignore_path, stat.S_IXGRP)
                 os.chmod(ignore_path, stat.S_IWGRP)
@@ -282,31 +221,6 @@ class CodeCounter(object):
             return res[-1]["include"]
             # selected_rule = max(res, key=lambda rule: len(str(rule["pattern"])))
 
-    @classmethod
-    def adjudgment_type(cls, file: str) -> str:
-        """Get file type.
-
-        First, judge whether the file name is special, and then query the
-        file suffix. Otherwise, the suffix or name will be returned as is.
-
-        Args:
-            file (str): file name string.
-
-        Returns:
-            (str): file type.
-        """
-
-        pre_type = cls.Special_Names.get(file.lower(), None)
-        if pre_type:
-            return pre_type
-
-        suffix = file.split(".")[-1]
-        suffix_type = cls.Suffix_Types.get(suffix.lower(), None)
-        if suffix_type:
-            return suffix_type
-        else:
-            return suffix
-
     def _sub_count(self, root: str, files: list) -> tuple:
         """Process handle use by `self.count`."""
         result = {}  # type: dict[str,dict]
@@ -323,10 +237,10 @@ class CodeCounter(object):
                     size_ = os.path.getsize(full_path)
                     total_size += size_
                 except:
-                    pass
+                    Log.debug(f"Can't read size of '{full_path}'")
 
                 # Get file type.
-                type_ = self.adjudgment_type(file)
+                type_ = adjudgment_type(file, original=True)
                 try:
                     with open(full_path) as f:
                         count = len(f.read().split("\n"))
@@ -360,8 +274,8 @@ class CodeCounter(object):
 
         Args:
             root_path (str): The path is walk needed.
-            use_ignore (bool): Wether ignore files in `.gitignore`. Defaults to True.
-            progress (bool): Wether show processing. Defaults to True.
+            use_ignore (bool): Whether ignore files in `.gitignore`. Defaults to True.
+            progress (bool): Whether show processing. Defaults to True.
 
         Return:
             result (dict): Dictionary containing statistical results.
@@ -432,6 +346,7 @@ class CodeCounter(object):
 
                 if not files:
                     continue
+
                 # print(pool._queue_count)
                 if len(files) >= 15 and pool._queue_count < max_queue:
                     # Calling process.
@@ -448,10 +363,10 @@ class CodeCounter(object):
                                 with self._Lock:
                                     data_count[0] += size_
                             except:
-                                pass
+                                Log.debug(f"Can't read size of '{full_path}'")
 
                             # Get file type.
-                            type_ = self.adjudgment_type(file)
+                            type_ = adjudgment_type(file, original=True)
                             try:
                                 with open(full_path) as f:
                                     count = len(f.read().split("\n"))
@@ -502,11 +417,12 @@ class CodeCounter(object):
         try:
             with open(file_path) as rf:
                 res = json.load(rf)
-                return res
         except Exception:
             return None
+        else:
+            return res
 
-    def save_result(self, result: dict, root_path: str) -> None:
+    def save_result(self, result: dict, root_path: str) -> bool:
         """Save count result.
 
         Generate name according to `root_path`, then try save the record
@@ -517,7 +433,7 @@ class CodeCounter(object):
             root_path (str): Traversal directory.
 
         Return:
-            (bool): Wether saving successful.
+            (bool): Whether saving successful.
         """
 
         file_path = self._get_file_path(root_path)
@@ -525,9 +441,10 @@ class CodeCounter(object):
         try:
             with open(file_path, "w" if os.path.isfile(file_path) else "x") as wf:
                 json.dump(result, wf, indent=2)
-                return True
         except Exception:
             return False
+        else:
+            return True
 
     @classmethod
     def color_index(cls, _count: int) -> int:
@@ -552,32 +469,28 @@ class CodeCounter(object):
         width, _ = get_terminal_size()
         if result_format == "simple" or width < needed_width:
             for key, value in new.items():
-                line = "{}: {:,} | {:,}".format(key, value["files"], value["lines"])
+                line = "::{} -> {:,} | {:,}".format(key, value["files"], value["lines"])
                 print(line)
-            return
+            return None
 
         elif result_format == "table":
+            title = "[Code Counter Result]"
+            header = ["Language", "Files", "Code lines"]
+
             # Print full time.
             print(time.strftime("%H:%M:%S %a %Y-%m-%d %Z", time.localtime()))
-            # Print title.
-            print("{}{:^67}{}".format(Fx.bold, "[Code Counter Result]", Fx.unbold))
-            # Print table header.
-            print("=" * needed_width)
-            print(
-                "| {bold}{:<21}{unbold}| {bold}{:<17}{unbold}| {bold}{:<22}{unbold}|".format(
-                    "Language", "Files", "Code lines", bold=Fx.bold, unbold=Fx.unbold
-                )
-            )
-            print("|{sep:-<22}|{sep:-<18}|{sep:-<23}|".format(sep="-"))
-            # Print table content.
+
+            # Diff
             sum_ = 0
             additions = 0
             deletions = 0
+            tb_data = []
             for key, value in new.items():
                 if self.use_icon:
                     key_display_str = "{0} {1}".format(get_file_icon(key), key)
                 else:
                     key_display_str = key
+
                 # Processing too long name.
                 key_display_str = shorten(key_display_str, 20, front=False)
 
@@ -609,26 +522,23 @@ class CodeCounter(object):
                 else:
                     files_change = files_symbol = lines_change = lines_symbol = ""
 
-                print(
-                    (
-                        "| {:<21}"
-                        "| {file_style}{:<11,}{reset} {file_change_style}{file_change:>5}{reset}"
-                        "| {lines_style}{:<15,}{reset} {line_change_style}{line_change:>6}{reset}|"
-                    ).format(
-                        key_display_str,
-                        value["files"],
-                        value["lines"],
-                        file_style=Fx.italic,
-                        file_change_style=self.symbol_color.get(files_symbol, ""),
-                        file_change=files_change,
-                        lines_style=lines_color,
-                        line_change_style=self.symbol_color.get(lines_symbol, ""),
-                        line_change=lines_change,
-                        reset=Fx.reset,
-                    )
+                file_symbol = self.symbol_color.get(files_symbol, "")
+                line_symbol = self.symbol_color.get(lines_symbol, "")
+                tb_data.append(
+                    [
+                        f" {key_display_str:<21}",
+                        f" {Fx.i}{value['files']:<11}{Fx.rs} {file_symbol}{files_change:>5}{Fx.rs}",
+                        f" {Fx.i}{value['lines']:<15}{Fx.rs} {line_symbol}{lines_change:>6}{Fx.rs}",
+                    ]
                 )
+
+                # Clac sum code line.
                 sum_ += value["lines"]
-            print("-" * needed_width)
+
+            # Print table.
+            tb = Table(header, tb_data, title=title)
+            tb.print()
+
             # Print total and change graph.
             print(" Total: {0}".format(sum_))
 
@@ -657,6 +567,7 @@ class CodeCounter(object):
         result, invalid_list, total_size = self.count(self.count_path, self.use_ignore)
 
         old_result = self.load_recorded_result(self.count_path)
+
         # diff print.
         self.format_print(result, old_result)
         if if_save:
@@ -664,7 +575,7 @@ class CodeCounter(object):
         if (
             show_invalid
             and invalid_list
-            and confirm("Wether print invalid file list?[y/n]", default=False)
+            and confirm("Whether print invalid file list?[y/n]", default=False)
         ):
             print(invalid_list)
 
