@@ -7,10 +7,10 @@ from shutil import get_terminal_size
 from typing import Optional
 
 from ..utils import color_print, exec_cmd, run_cmd, confirm
-from ..str_utils import shorten, get_width
 from ..common import Fx, Color, TermColor
+from ..common.str_utils import shorten, get_width
 from ..keyevent import get_keyevent_obj
-from ..git_utils import IS_Git_Repository
+from ..git_utils import REPOSITORY_PATH
 from .model import File
 
 
@@ -26,7 +26,6 @@ class DataHandle(object):
         self.use_color = use_color
 
     def get_status(self, max_width: int, ident: int = 2) -> list[File]:
-        # type:(int, int) -> list[File]
         """Get the file tree status of GIT for processing and encapsulation.
 
         Args:
@@ -103,7 +102,7 @@ class DataHandle(object):
             file (str): file path relative to git.
             tracked (bool, optional): Defaults to True.
             cached (bool, optional): Defaults to False.
-            plain (bool, optional): Wether need color. Defaults to False.
+            plain (bool, optional): Whether need color. Defaults to False.
 
         Returns:
             (str): change string.
@@ -167,15 +166,16 @@ class InteractiveAdd(object):
         self._min_width = 60
         self._debug = debug
 
-        self._keyevent = get_keyevent_obj()
-        # Wether can into interactive.
-        if not self._keyevent:
+        # Whether can into interactive.
+        try:
+            _keyevent_class = get_keyevent_obj()
+        except NameError:
             raise TermError("This behavior is not supported in the current system.")
+        self._keyevent = _keyevent_class()
 
         self._data_handle = DataHandle(use_color)
 
-    def process_file(self, file: str) -> None:
-        # type:(File) -> None
+    def process_file(self, file: File) -> None:
         """Process file to change the status.
 
         Args:
@@ -331,7 +331,7 @@ class InteractiveAdd(object):
     def add_interactive(self, *args):
         """Interactive main method."""
 
-        if not IS_Git_Repository:
+        if not REPOSITORY_PATH:
             color_print("Current path is not a git repository.", TermColor.Red)
             return
 
@@ -363,17 +363,14 @@ class InteractiveAdd(object):
         # Into new term page.
         print(Fx.alt_screen + Fx.hide_cursor)
         try:
-            try:
-                #  try hook window resize event.
-                self._keyevent.signal_init()
-            except AttributeError:
-                pass
+            #  try hook window resize event.
+            self._keyevent.signal_init()
 
             # Start interactive.
             while not stopping:
                 print(Fx.clear_)
 
-                # check wether have status.
+                # check whether have status.
                 if not file_items:
                     print("The work tree is clean and there is nothing to operate.")
                     time.sleep(1)
@@ -461,8 +458,5 @@ class InteractiveAdd(object):
             pass
         finally:
             # Whatever, unregister signal event and restore terminal at last.
-            try:
-                self._keyevent.signal_restore()
-            except AttributeError:
-                pass
+            self._keyevent.signal_restore()
             print(Fx.normal_screen + Fx.show_cursor)
