@@ -3,6 +3,7 @@
 import os
 import re
 import logging
+from typing import Optional
 from urllib.request import urlopen
 
 from .utils import confirm
@@ -75,7 +76,7 @@ class GitignoreGenetor(object):
         res = re.sub(r"(\n[^\S\r\n]+)+", "\n", res)
         return res
 
-    def get_html_from_url(self, url: str) -> str:
+    def get_html_from_url(self, url: str) -> Optional[str]:
         """Crawl gitignore template.
 
         Args:
@@ -88,12 +89,11 @@ class GitignoreGenetor(object):
         try:
             handle = urlopen(url, timeout=self.timeout)
         except Exception as e:
-            Log.error(str(e))
+            Log.error(str(e) + str(e.__traceback__))
             # Exit once an error occurs.
             return None
         else:
             content = handle.read().decode("utf-8")
-
             return content
 
     def launch(self, genre: str, dir_path: str) -> None:
@@ -113,12 +113,12 @@ class GitignoreGenetor(object):
                     " ".join(self.Supported_Types.keys())
                 )
             )
-            return
+            return None
 
         ignore_path = dir_path + "/.gitignore"
         whether_write = True
 
-        # Adjust `.gitignore` wether exist.
+        # Adjust `.gitignore` whether exist.
         if os.path.exists(ignore_path):
             whether_write = confirm(
                 "`.gitignore` existed, overwrite this file? (default: y) [y/n]:"
@@ -135,7 +135,7 @@ class GitignoreGenetor(object):
             content = self.get_html_from_url(target_url)
             if not content:
                 print("Failed to get content and will exit.")
-                return
+                return None
 
             ignore_content = self.parse_gitignore_page(content)
 
@@ -143,12 +143,13 @@ class GitignoreGenetor(object):
             try:
                 with open(ignore_path, "w") as fd:
                     fd.write(ignore_content)
-                print(
-                    "Write gitignore file successful. {0}".format(Emotion.Icon_Smiler)
-                )
             except Exception as e:
-                Log.error(str(e))
+                Log.error(str(e) + str(e.__traceback__))
                 print("Write gitignore file failed.")
                 print("You can copy it with the following:")
                 print("#" * 60)
                 print(ignore_content)
+            else:
+                print(
+                    "Write gitignore file successful. {0}".format(Emotion.Icon_Smiler)
+                )
